summaryrefslogtreecommitdiffstats
path: root/drivers/gpu/drm/amd/amdgpu/vce_v3_0.c
diff options
context:
space:
mode:
authorFlora Cui <Flora.Cui@amd.com>2016-03-14 18:33:29 -0400
committerAlex Deucher <alexander.deucher@amd.com>2016-05-04 20:27:57 -0400
commit2cc0c0b5cd4d07a65267c28a4f7b68134abff472 (patch)
tree6f989d1e7fb5706e171c08881720ba8da8734bfc /drivers/gpu/drm/amd/amdgpu/vce_v3_0.c
parenta3ad7a9ad8ef2e87ffa7e65d6ce0e9928b4134e9 (diff)
downloadlinux-2cc0c0b5cd4d07a65267c28a4f7b68134abff472.tar.bz2
drm/amdgpu: change ELM/BAF to Polaris10/Polaris11
Adjust to preferred code names. Signed-off-by: Flora Cui <Flora.Cui@amd.com> Reviewed-by: Alex Deucher <alexander.deucher@amd.com> Signed-off-by: Alex Deucher <alexander.deucher@amd.com>
Diffstat (limited to 'drivers/gpu/drm/amd/amdgpu/vce_v3_0.c')
-rw-r--r--drivers/gpu/drm/amd/amdgpu/vce_v3_0.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/drivers/gpu/drm/amd/amdgpu/vce_v3_0.c b/drivers/gpu/drm/amd/amdgpu/vce_v3_0.c
index c12fd832c884..58342853b69c 100644
--- a/drivers/gpu/drm/amd/amdgpu/vce_v3_0.c
+++ b/drivers/gpu/drm/amd/amdgpu/vce_v3_0.c
@@ -315,11 +315,11 @@ static unsigned vce_v3_0_get_harvest_config(struct amdgpu_device *adev)
{
u32 tmp;
/* Fiji, Stoney, Ellesmere, Baffin are single pipe */
if ((adev->asic_type == CHIP_FIJI) ||
(adev->asic_type == CHIP_STONEY) ||
- (adev->asic_type == CHIP_ELLESMERE) ||
- (adev->asic_type == CHIP_BAFFIN))
+ (adev->asic_type == CHIP_POLARIS10) ||
+ (adev->asic_type == CHIP_POLARIS11))
return AMDGPU_VCE_HARVEST_VCE1;
/* Tonga and CZ are dual or single pipe */
@@ -315,11 +315,11 @@ static unsigned vce_v3_0_get_harvest_config(struct amdgpu_device *adev)
{
u32 tmp;
- /* Fiji, Stoney, Ellesmere, Baffin are single pipe */
+ /* Fiji, Stoney, Polaris10, Polaris11 are single pipe */
if ((adev->asic_type == CHIP_FIJI) ||
(adev->asic_type == CHIP_STONEY) ||